<?php

if (!class_exists('WP_Import_Process')) {
	class WP_Import_Process extends WP_Background_Process {
	
	    /**
	     * @var string
	     */
	    protected $action = 'import_process';
	    
	    var $data = array();
	    
	    var $counter_reset = 100;
	    
	    public function __construct() {
			parent::__construct();
		}
		
		public function get_batch() {
			return parent::get_batch();
		}
		
		public function queued_items() {
			if ($this -> is_queue_empty()) {
				return false;
			}
			
			return true;
		}
		
		public function get_data() {
			return $this -> data;
		}
	    
	    public function reset_data() {
		    $this -> data = array();
	    }
	    
	    function get_batches($onlykeys = false) {
		    global $wpdb;

			$table        = $wpdb->options;
			$column       = 'option_name';
			$key_column   = 'option_id';
			$value_column = 'option_value';

			if ( is_multisite() ) {
				$table        = $wpdb->sitemeta;
				$column       = 'meta_key';
				$key_column   = 'meta_id';
				$value_column = 'meta_value';
			}

			$key = $this->identifier . '_batch_%';

			$query = $wpdb->prepare( "
			SELECT *
			FROM {$table}
			WHERE {$column} LIKE %s
			ORDER BY {$key_column} ASC", $key );

			$results = $wpdb->get_results($query);
			
			$batches = array();
			
			if (!empty($results)) {
				foreach ($results as $result) {
					$batch = new stdClass();
					$batch -> key = $result -> {$column};
					
					if (empty($onlykeys)) {
						$batch -> data = maybe_unserialize($result -> {$value_column});
					}
					
					$batches[] = $batch;
					
					if ($this -> memory_exceeded()) {
						$this -> memory_exceeded = true;
						return $batches;
					}
				}
			}

			return $batches;
	    }
	    
	    function cancel_all_processes() {
		    if ($batches = $this -> get_batches(true)) {
			    foreach ($batches as $batch) {
				    $this -> delete($batch -> key);
			    }
		    }
		    
		    parent::complete();
		    return true;
	    }
	
	    /**
	     * Task
	     *
	     * Override this method to perform any actions required on each
	     * queue item. Return the modified item for further processing
	     * in the next pass through. Or, return false to remove the
	     * item from the queue.
	     *
	     * @param mixed $item Queue item to iterate over
	     *
	     * @return mixed
	     */
	    protected function task( $item ) {
	        // Actions to perform
	        
	        global $wpMail, $Db, $Queue, $Subscriber;
	        
	        if (!empty($item)) {
		        $subscriber = $item['subscriber'];
		        $skipsubscriberupdate = (empty($item['options']['skipsubscriberupdate'])) ? false : true;
		        $confirmation = (!empty($item['options']['confirmation'])) ? true : false;
		        
		        if ($Subscriber -> save($subscriber, true, false, $skipsubscriberupdate)) {
					if (!empty($confirmation)) {
						$confirmation_subject = $item['options']['confirmation']['confirmation_subject'];
						$confirmation_email = $item['options']['confirmation']['confirmation_email'];
						
						$Db -> model = $Subscriber -> model;
						$subscriber = $Db -> find(array('id' => $Subscriber -> insertid));
	
						foreach ($subscriber['mailinglists'] as $list_id) {
							$queue_process_data = array(
								'subscriber_id'				=>	$subscriber -> id,
								'subject'					=>	$confirmation_subject,
								'message'					=>	$confirmation_email,
								'attachments'				=>	false,
								'post_id'					=>	false,
								'history_id'				=>	false,
								'theme_id'					=>	$wpMail -> default_theme_id('system'),
								'senddate'					=>	false,
							);
							
							$wpMail -> queue_process -> push_to_queue($queue_process_data);
							$wpMail -> queue_process -> save() -> dispatch();
						}
					}
				} else {
					$wpMail -> log_error(sprintf(__('Subscriber (%s) could not be imported: %s', $wpMail -> plugin_name), $subscriber -> email, implode(", ", $Subscriber -> errors)));
				}
			}
	        
	        return false;
	    }
	
	    /**
	     * Complete
	     *
	     * Override if applicable, but ensure that the below actions are
	     * performed, or, call parent::complete().
	     */
	    protected function complete() {
		    
		    global $wpMail;
		    $wpMail -> admin_notification_import_complete();
		    
	        parent::complete();
	
	        // Show notice to user or perform some other arbitrary task...
	    }
	
	}
}